# Generated by Django 3.0.7 on 2020-06-25 03:45

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
            ],
            options={
                'db_table': 'log',
            },
        ),
        migrations.CreateModel(
            name='Query',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
            ],
            options={
                'db_table': 'log_query',
            },
        ),
    ]



from __future__ import annotations

from typing import Optional

from django.apps import apps

class InteligerMeta(type):
    _instance: Optional[Inteliger] = None

    def __call__(self) -> Inteliger:
        if self._instance is None:
            self._instance = super().__call__()
        return self._instance


class Inteliger(metaclass=InteligerMeta):
    def __init__(self):
        self.__tempo_pesquisa = 0
        self.atualizar_tempo_query()

    def salvar_log(self, request=None, response=None):
        if request.META.get('REMOTE_ADDR') != '127.0.0.1':
            Log = apps.get_model('log', 'Log')
            Log(
                status_code=response.status_code,
                reason_phrase=response.reason_phrase,
                metodo=request.method,
                ip=request.META.get('REMOTE_ADDR'),
                path=request.path,
                session_key=request.session.session_key,
                body=str(request.body),
            ).save()

    def atualizar_tempo_query(self):
        Tipo = apps.get_model('core', 'Tipo')
        tempo = Tipo.normal_objects.values('nome').filter(tipo='SISTEMA.TEMPO_QUERY').order_by('-dat_insercao').first()
        try:
            self.tempo_pesquisa = int(tempo['nome']) if tempo is not None else 0
        except:
            pass

    @property
    def tempo_pesquisa(self):
        return self.__tempo_pesquisa

    @tempo_pesquisa.setter
    def tempo_pesquisa(self, tempo):
        self.__tempo_pesquisa = tempo



# Generated by Django 3.0.7 on 2020-06-25 03:45

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Tipo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('codigo', models.IntegerField(null=True)),
                ('tipo', models.CharField(max_length=200, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('descricao', models.TextField(null=True)),
            ],
            options={
                'db_table': 'tipo',
            },
        ),
    ]



from django.db import models
import core.models


class Log(core.models.Log):
    status_code = models.IntegerField(null=True)
    reason_phrase = models.CharField(max_length=500, null=True)
    metodo = models.CharField(max_length=30, null=True)
    ip = models.GenericIPAddressField(null=True)
    path = models.CharField(max_length=500, null=True)
    session_key = models.CharField(max_length=200, null=True)
    body = models.TextField(null=True)

    class Meta:
        #db_table = u'"log\".\"log"'
        db_table = 'log'


class Query(core.models.Log):
    time = models.FloatField(null=True)
    query = models.TextField(null=True)

    class Meta:
        #db_table = u'"log\".\"log_query"'
        db_table = 'log_query'


from django.db import models
import core.models


class Filial(core.models.Log):
    codigo = models.IntegerField(null=True, unique=True)
    filial = models.CharField(max_length=500, null=True)
    cnpj = models.CharField(max_length=200, null=True)

    class Meta:
        #db_table = u'"core\".\"filial"'
        db_table = 'filial'


class Servico(core.models.Log):
    nome = models.CharField(max_length=200, null=True)
    descricao = models.TextField(null=True)
    filial = models.ManyToManyField(Filial, through='RelacaoServicos')

    class Meta:
        #db_table = u'"core\".\"filial_servico"'
        db_table = 'filial_servico'


class RelacaoServicos(core.models.Log):
    filial = models.ForeignKey(Filial, on_delete=models.CASCADE)
    servico = models.ForeignKey(Servico, on_delete=models.CASCADE)

    class Meta:
        #db_table = u'"core\".\"filial_relacaoservico"'
        db_table = 'filial_relacaoservico'
        unique_together = ('filial', 'servico')


# Generated by Django 3.0.7 on 2020-06-25 03:45

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filial', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name='servico',
            name='usr_delete',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_servico_usr_delete', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='servico',
            name='usr_edicao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_servico_usr_edicao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='servico',
            name='usr_insercao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_servico_usr_insercao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='filial',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='filial.Filial'),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='servico',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='filial.Servico'),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='usr_delete',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_relacaoservicos_usr_delete', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='usr_edicao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_relacaoservicos_usr_edicao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='usr_insercao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_relacaoservicos_usr_insercao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filial',
            name='usr_delete',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_filial_usr_delete', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filial',
            name='usr_edicao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_filial_usr_edicao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filial',
            name='usr_insercao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_filial_usr_insercao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterUniqueTogether(
            name='relacaoservicos',
            unique_together={('filial', 'servico')},
        ),
    ]



from django.db import models
import core.models
from django.contrib.auth.models import AbstractUser
from compositefk.fields import CompositeForeignKey


class Profile(AbstractUser, core.models.Log):
    nm_completo = models.CharField(max_length=200, null=True)

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE.TIPO')
    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.SET_NULL, null=True, related_name='usr_profile_tipo', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    class Meta:
        #db_table = u'"core\".\"profile"'
        db_table = 'profile'